==> zjkj-wzxt-impl-3.0.0-20240806.025714-25-sources.jar: com/ejianc/wzxt/plan/bean/MasterPlanDetailChangeHisEntity.java <==
package com.ejianc.wzxt.plan.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 材料总控计划历史-子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_master_plan_detail_change_his")
public class MasterPlanDetailChangeHisEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="material_master_plan_id")
    private Long materialMasterPlanId; // 所属总计划Id
    @TableField(value="material_category_id")
    private Long materialCategoryId; // 物资分类Id
    @TableField(value="material_category_name")
    private String materialCategoryName; // 物资分类名称
    @TableField(value="material_id")
    private Long materialId; // 物资Id
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="unit")
    private String unit; // 计量单位
    @TableField(value="tender_num")
    private BigDecimal tenderNum; // 标书数量
    @TableField(value="tender_price")
    private BigDecimal tenderPrice; // 标书单价
    @TableField(value="tender_amount")
    private BigDecimal tenderAmount; // 标书金额
    @TableField(value="change_type")
    private Integer changeType; // 变更类型: 1-增补项，2-删除项，3-变更项
    @TableField(value="target_id")
    private Long targetId; // 变更项原数据Id
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="material_code")
    private String materialCode; // 物资编码
    @TableField(value="unit_id")
    private Long unitId; // 计量单位Id
    @TableField(value="response_num")
    private BigDecimal responseNum; // 责任成本量
    @TableField(value="response_surplus_num")
    private BigDecimal responseSurplusNum; // 责任成本剩余量
    @TableField(value="plan_total_num")
    private BigDecimal planTotalNum; // 总控计划量
    @TableField(value="plan_month_num")
    private BigDecimal planMonthNum; // 月计划量
    @TableField(value="order_num")
    private BigDecimal orderNum; // 订单量
    @TableField(value="check_num")
    private BigDecimal checkNum; // 验收量
    
    
    

    public Long getMaterialMasterPlanId() {
        return materialMasterPlanId;
    }

    public void setMaterialMasterPlanId(Long materialMasterPlanId) {
        this.materialMasterPlanId = materialMasterPlanId;
    }
    public Long getMaterialCategoryId() {
        return materialCategoryId;
    }

    public void setMaterialCategoryId(Long materialCategoryId) {
        this.materialCategoryId = materialCategoryId;
    }
    public String getMaterialCategoryName() {
        return materialCategoryName;
    }

    public void setMaterialCategoryName(String materialCategoryName) {
        this.materialCategoryName = materialCategoryName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public BigDecimal getTenderNum() {
        return tenderNum;
    }

    public void setTenderNum(BigDecimal tenderNum) {
        this.tenderNum = tenderNum;
    }
    public BigDecimal getTenderPrice() {
        return tenderPrice;
    }

    public void setTenderPrice(BigDecimal tenderPrice) {
        this.tenderPrice = tenderPrice;
    }
    public BigDecimal getTenderAmount() {
        return tenderAmount;
    }

    public void setTenderAmount(BigDecimal tenderAmount) {
        this.tenderAmount = tenderAmount;
    }
    public Integer getChangeType() {
        return changeType;
    }

    public void setChangeType(Integer changeType) {
        this.changeType = changeType;
    }
    public Long getTargetId() {
        return targetId;
    }

    public void setTargetId(Long targetId) {
        this.targetId = targetId;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public BigDecimal getResponseNum() {
        return responseNum;
    }

    public void setResponseNum(BigDecimal responseNum) {
        this.responseNum = responseNum;
    }
    public BigDecimal getResponseSurplusNum() {
        return responseSurplusNum;
    }

    public void setResponseSurplusNum(BigDecimal responseSurplusNum) {
        this.responseSurplusNum = responseSurplusNum;
    }
    public BigDecimal getPlanTotalNum() {
        return planTotalNum;
    }

    public void setPlanTotalNum(BigDecimal planTotalNum) {
        this.planTotalNum = planTotalNum;
    }
    public BigDecimal getPlanMonthNum() {
        return planMonthNum;
    }

    public void setPlanMonthNum(BigDecimal planMonthNum) {
        this.planMonthNum = planMonthNum;
    }
    public BigDecimal getOrderNum() {
        return orderNum;
    }

    public void setOrderNum(BigDecimal orderNum) {
        this.orderNum = orderNum;
    }
    public BigDecimal getCheckNum() {
        return checkNum;
    }

    public void setCheckNum(BigDecimal checkNum) {
        this.checkNum = checkNum;
    }
    
}

==> zjkj-wzxt-impl-3.0.0-20240816.093915-98-sources.jar: com/ejianc/wzxt/plan/bean/MasterPlanDetailChangeHisEntity.java <==
package com.ejianc.wzxt.plan.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 材料总控计划历史-子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_master_plan_detail_change_his")
public class MasterPlanDetailChangeHisEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="material_master_plan_id")
    private Long materialMasterPlanId; // 所属总计划Id
    @TableField(value="material_category_id")
    private Long materialCategoryId; // 物资分类Id
    @TableField(value="material_category_name")
    private String materialCategoryName; // 物资分类名称
    @TableField(value="material_id")
    private Long materialId; // 物资Id
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="unit")
    private String unit; // 计量单位
    @TableField(value="tender_num")
    private BigDecimal tenderNum; // 标书数量
    @TableField(value="tender_price")
    private BigDecimal tenderPrice; // 标书单价
    @TableField(value="tender_amount")
    private BigDecimal tenderAmount; // 标书金额
    @TableField(value="change_type")
    private Integer changeType; // 变更类型: 1-增补项，2-删除项，3-变更项
    @TableField(value="target_id")
    private Long targetId; // 变更项原数据Id
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="material_code")
    private String materialCode; // 物资编码
    @TableField(value="unit_id")
    private Long unitId; // 计量单位Id
    @TableField(value="response_num")
    private BigDecimal responseNum; // 责任成本量
    @TableField(value="response_surplus_num")
    private BigDecimal responseSurplusNum; // 责任成本剩余量
    @TableField(value="plan_total_num")
    private BigDecimal planTotalNum; // 总控计划量
    @TableField(value="plan_month_num")
    private BigDecimal planMonthNum; // 月计划量
    @TableField(value="order_num")
    private BigDecimal orderNum; // 订单量
    @TableField(value="check_num")
    private BigDecimal checkNum; // 验收量

    @TableField(value="material_category_code")
    private String materialCategoryCode;

    public String getMaterialCategoryCode() {
        return materialCategoryCode;
    }

    public void setMaterialCategoryCode(String materialCategoryCode) {
        this.materialCategoryCode = materialCategoryCode;
    }

    public Long getMaterialMasterPlanId() {
        return materialMasterPlanId;
    }

    public void setMaterialMasterPlanId(Long materialMasterPlanId) {
        this.materialMasterPlanId = materialMasterPlanId;
    }
    public Long getMaterialCategoryId() {
        return materialCategoryId;
    }

    public void setMaterialCategoryId(Long materialCategoryId) {
        this.materialCategoryId = materialCategoryId;
    }
    public String getMaterialCategoryName() {
        return materialCategoryName;
    }

    public void setMaterialCategoryName(String materialCategoryName) {
        this.materialCategoryName = materialCategoryName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public BigDecimal getTenderNum() {
        return tenderNum;
    }

    public void setTenderNum(BigDecimal tenderNum) {
        this.tenderNum = tenderNum;
    }
    public BigDecimal getTenderPrice() {
        return tenderPrice;
    }

    public void setTenderPrice(BigDecimal tenderPrice) {
        this.tenderPrice = tenderPrice;
    }
    public BigDecimal getTenderAmount() {
        return tenderAmount;
    }

    public void setTenderAmount(BigDecimal tenderAmount) {
        this.tenderAmount = tenderAmount;
    }
    public Integer getChangeType() {
        return changeType;
    }

    public void setChangeType(Integer changeType) {
        this.changeType = changeType;
    }
    public Long getTargetId() {
        return targetId;
    }

    public void setTargetId(Long targetId) {
        this.targetId = targetId;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public BigDecimal getResponseNum() {
        return responseNum;
    }

    public void setResponseNum(BigDecimal responseNum) {
        this.responseNum = responseNum;
    }
    public BigDecimal getResponseSurplusNum() {
        return responseSurplusNum;
    }

    public void setResponseSurplusNum(BigDecimal responseSurplusNum) {
        this.responseSurplusNum = responseSurplusNum;
    }
    public BigDecimal getPlanTotalNum() {
        return planTotalNum;
    }

    public void setPlanTotalNum(BigDecimal planTotalNum) {
        this.planTotalNum = planTotalNum;
    }
    public BigDecimal getPlanMonthNum() {
        return planMonthNum;
    }

    public void setPlanMonthNum(BigDecimal planMonthNum) {
        this.planMonthNum = planMonthNum;
    }
    public BigDecimal getOrderNum() {
        return orderNum;
    }

    public void setOrderNum(BigDecimal orderNum) {
        this.orderNum = orderNum;
    }
    public BigDecimal getCheckNum() {
        return checkNum;
    }

    public void setCheckNum(BigDecimal checkNum) {
        this.checkNum = checkNum;
    }
    
}
